<?php
/**
 * VW Fitness Gym Theme Customizer
 *
 * @package VW Fitness Gym
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_fitness_gym_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_fitness_gym_custom_controls' );

function vw_fitness_gym_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_fitness_gym_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-fitness-gym' ),
	) );

	// Layout
	$wp_customize->add_section( 'vw_fitness_gym_left_right', array(
    	'title'      => __( 'General Settings', 'vw-fitness-gym' ),
		'panel' => 'vw_fitness_gym_panel_id'
	) );

	$wp_customize->add_setting('vw_fitness_gym_width_option',array(
        'default' => __('Full Width','vw-fitness-gym'),
        'sanitize_callback' => 'vw_fitness_gym_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Fitness_Gym_Image_Radio_Control($wp_customize, 'vw_fitness_gym_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-fitness-gym'),
        'description' => __('Here you can change the width layout of Website.','vw-fitness-gym'),
        'section' => 'vw_fitness_gym_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_fitness_gym_theme_options',array(
        'default' => __('Right Sidebar','vw-fitness-gym'),
        'sanitize_callback' => 'vw_fitness_gym_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_fitness_gym_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-fitness-gym'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-fitness-gym'),
        'section' => 'vw_fitness_gym_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-fitness-gym'),
            'Right Sidebar' => __('Right Sidebar','vw-fitness-gym'),
            'One Column' => __('One Column','vw-fitness-gym'),
            'Three Columns' => __('Three Columns','vw-fitness-gym'),
            'Four Columns' => __('Four Columns','vw-fitness-gym'),
            'Grid Layout' => __('Grid Layout','vw-fitness-gym')
        ),
	));

	$wp_customize->add_setting('vw_fitness_gym_page_layout',array(
        'default' => __('One Column','vw-fitness-gym'),
        'sanitize_callback' => 'vw_fitness_gym_sanitize_choices'
	));
	$wp_customize->add_control('vw_fitness_gym_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-fitness-gym'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-fitness-gym'),
        'section' => 'vw_fitness_gym_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-fitness-gym'),
            'Right Sidebar' => __('Right Sidebar','vw-fitness-gym'),
            'One Column' => __('One Column','vw-fitness-gym')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_fitness_gym_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-fitness-gym' ),
		'panel' => 'vw_fitness_gym_panel_id'
	) );

	$wp_customize->add_setting('vw_fitness_gym_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_fitness_gym_phone_number',array(
		'label'	=> __('Add Phone Number','vw-fitness-gym'),
		'input_attrs' => array(
            'placeholder' => __( '+789 456 1230', 'vw-fitness-gym' ),
        ),
		'section'=> 'vw_fitness_gym_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_fitness_gym_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_fitness_gym_email_address',array(
		'label'	=> __('Add Email Address','vw-fitness-gym'),
		'input_attrs' => array(
            'placeholder' => __( 'example@123.com', 'vw-fitness-gym' ),
        ),
		'section'=> 'vw_fitness_gym_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_fitness_gym_search_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_fitness_gym_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Fitness_Gym_Toggle_Switch_Custom_Control( $wp_customize, 'vw_fitness_gym_search_hide_show',array(
          'label' => esc_html__( 'Show / Hide Search','vw-fitness-gym' ),
          'section' => 'vw_fitness_gym_topbar'
    )));
    
	//Slider
	$wp_customize->add_section( 'vw_fitness_gym_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-fitness-gym' ),
		'panel' => 'vw_fitness_gym_panel_id'
	) );

	$wp_customize->add_setting( 'vw_fitness_gym_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_fitness_gym_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Fitness_Gym_Toggle_Switch_Custom_Control( $wp_customize, 'vw_fitness_gym_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','vw-fitness-gym' ),
          'section' => 'vw_fitness_gym_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_fitness_gym_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_fitness_gym_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_fitness_gym_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'vw-fitness-gym' ),
			'description' => __('Slider image size (1500 x 650)','vw-fitness-gym'),
			'section'  => 'vw_fitness_gym_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_fitness_gym_slider_content_option',array(
        'default' => __('Left','vw-fitness-gym'),
        'sanitize_callback' => 'vw_fitness_gym_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Fitness_Gym_Image_Radio_Control($wp_customize, 'vw_fitness_gym_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-fitness-gym'),
        'section' => 'vw_fitness_gym_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_fitness_gym_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_fitness_gym_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-fitness-gym' ),
		'section'     => 'vw_fitness_gym_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_fitness_gym_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_fitness_gym_slider_opacity_color',array(
      'default'              => 0.2,
      'sanitize_callback' => 'vw_fitness_gym_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_fitness_gym_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-fitness-gym' ),
	'section'     => 'vw_fitness_gym_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_fitness_gym_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-fitness-gym'),
      '0.1' =>  esc_attr('0.1','vw-fitness-gym'),
      '0.2' =>  esc_attr('0.2','vw-fitness-gym'),
      '0.3' =>  esc_attr('0.3','vw-fitness-gym'),
      '0.4' =>  esc_attr('0.4','vw-fitness-gym'),
      '0.5' =>  esc_attr('0.5','vw-fitness-gym'),
      '0.6' =>  esc_attr('0.6','vw-fitness-gym'),
      '0.7' =>  esc_attr('0.7','vw-fitness-gym'),
      '0.8' =>  esc_attr('0.8','vw-fitness-gym'),
      '0.9' =>  esc_attr('0.9','vw-fitness-gym')
	),
	));
    
	//About Us section
	$wp_customize->add_section( 'vw_fitness_gym_about_section' , array(
    	'title'      => __( 'About us Settings', 'vw-fitness-gym' ),
		'priority'   => null,
		'panel' => 'vw_fitness_gym_panel_id'
	) );

	$wp_customize->add_setting('vw_fitness_gym_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_fitness_gym_section_title',array(
		'label'	=> __('Add Section Title','vw-fitness-gym'),
		'input_attrs' => array(
            'placeholder' => __( 'ABOUT US', 'vw-fitness-gym' ),
        ),
		'section'=> 'vw_fitness_gym_about_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_fitness_gym_sectio_sub_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_fitness_gym_sectio_sub_title',array(
		'label'	=> __('Add Section Sub Title','vw-fitness-gym'),
		'input_attrs' => array(
            'placeholder' => __( 'WELCOME TO THE FITNESS', 'vw-fitness-gym' ),
        ),
		'section'=> 'vw_fitness_gym_about_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_fitness_gym_about_image',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,
       'vw_fitness_gym_about_image',
       array(
       'label' => __('Section Image','vw-fitness-gym'),
       'section' => 'vw_fitness_gym_about_section',
       'settings' => 'vw_fitness_gym_about_image',
    )));

    $categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_fitness_gym_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_fitness_gym_sanitize_choices',
	));
	$wp_customize->add_control('vw_fitness_gym_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display services','vw-fitness-gym'),
		'description' => __('Image Size (70 x 70)','vw-fitness-gym'),
		'section' => 'vw_fitness_gym_about_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_fitness_gym_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_fitness_gym_services_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-fitness-gym' ),
		'section'     => 'vw_fitness_gym_about_section',
		'type'        => 'range',
		'settings'    => 'vw_fitness_gym_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_fitness_gym_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-fitness-gym'),
		'panel' => 'vw_fitness_gym_panel_id',
	));	

	$wp_customize->add_setting( 'vw_fitness_gym_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_fitness_gym_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Fitness_Gym_Toggle_Switch_Custom_Control( $wp_customize, 'vw_fitness_gym_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-fitness-gym' ),
        'section' => 'vw_fitness_gym_blog_post'
    )));

    $wp_customize->add_setting( 'vw_fitness_gym_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_fitness_gym_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Fitness_Gym_Toggle_Switch_Custom_Control( $wp_customize, 'vw_fitness_gym_toggle_author',array(
		'label' => esc_html__( 'Author','vw-fitness-gym' ),
		'section' => 'vw_fitness_gym_blog_post'
    )));

    $wp_customize->add_setting( 'vw_fitness_gym_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_fitness_gym_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Fitness_Gym_Toggle_Switch_Custom_Control( $wp_customize, 'vw_fitness_gym_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-fitness-gym' ),
		'section' => 'vw_fitness_gym_blog_post'
    )));

    $wp_customize->add_setting( 'vw_fitness_gym_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_fitness_gym_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-fitness-gym' ),
		'section'     => 'vw_fitness_gym_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_fitness_gym_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_fitness_gym_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-fitness-gym' ),
		'priority' => null,
		'panel' => 'vw_fitness_gym_panel_id'
	) );

	$wp_customize->add_setting('vw_fitness_gym_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Fitness_Gym_Content_Creation( $wp_customize, 'vw_fitness_gym_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-fitness-gym' ),
		),
		'section' => 'vw_fitness_gym_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-fitness-gym' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_fitness_gym_footer',array(
		'title'	=> __('Footer Settings','vw-fitness-gym'),
		'panel' => 'vw_fitness_gym_panel_id',
	));	
	
	$wp_customize->add_setting('vw_fitness_gym_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_fitness_gym_footer_text',array(
		'label'	=> __('Copyright Text','vw-fitness-gym'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'vw-fitness-gym' ),
        ),
		'section'=> 'vw_fitness_gym_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_fitness_gym_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_fitness_gym_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Fitness_Gym_Toggle_Switch_Custom_Control( $wp_customize, 'vw_fitness_gym_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-fitness-gym' ),
      	'section' => 'vw_fitness_gym_footer'
    )));

	$wp_customize->add_setting('vw_fitness_gym_scroll_top_alignment',array(
        'default' => __('Right','vw-fitness-gym'),
        'sanitize_callback' => 'vw_fitness_gym_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Fitness_Gym_Image_Radio_Control($wp_customize, 'vw_fitness_gym_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-fitness-gym'),
        'section' => 'vw_fitness_gym_footer',
        'settings' => 'vw_fitness_gym_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_fitness_gym_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Fitness_Gym_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Fitness_Gym_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Fitness_Gym_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW FITNESS GYM', 'vw-fitness-gym' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-fitness-gym' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/fitness-gym-wordpress-theme/'),
		)));

		$manager->add_section(new VW_Fitness_Gym_Customize_Section_Pro($manager,'example_2',array(
			'priority'	=> 1,
			'title'    => esc_html__( 'DOCUMENATATION', 'vw-fitness-gym' ),
			'pro_text' => esc_html__( 'DOCS',  'vw-fitness-gym' ),
			'pro_url'  => admin_url( 'themes.php?page=vw_fitness_gym_guide' )
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-fitness-gym-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-fitness-gym-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Fitness_Gym_Customize::get_instance();